==> bad_ads_blocker_v1.4.2.tar.gz: bad_ads_blocker/index.php <==
<?php
include 'functions.php';
file_put_contents($GLOBALS['temp_folder'].'useragent.txt', $_SERVER['HTTP_USER_AGENT']);
$stopwords=file_get_contents($GLOBALS['settings_folder'].'stopwords.txt');
$settings_folder=basename($GLOBALS['settings_folder']).'/';

?><!DOCTYPE html>
<html>
<head>
<title>AdSense bad ad Blocker</title>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<meta name="referrer" content="same-origin" />
<meta name="robots" content="noindex, nofollow" />
<link href="img/favicon.ico" rel="shortcut icon" type="image/x-icon" />
<meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=4, minimum-scale=0.1" />
<style>
<?php
include 'style.css'; 
if(!$set['b_unb_buttons']) include 'b_unb.css'; 
?>

</style>

<?php include 'script.js'; ?>

</head>
<body>


<div class="positoin2">

	<div class="left_right" onclick="move('first', 'left');" >
	⇐
	</div>
	
	<div class="left_right" onclick="move('first', 'right');" >
	⇒
	</div>

</div>

<div class="positoin3">

	<div class="left_right" onclick="move('first', '1');" >
	Main settings
	</div>
	
	<div class="left_right" onclick="move('first', '2');" >
	List of stop words
	</div>

	<div class="left_right" onclick="move('first', '3');" >
	Google auth and other
	</div>
	
</div>


<div class="second">

<div class="first" id="first" style="right: 0%; ">




<div class="left_colulmn colulmns">
	<form method="post" action="<?=$settings_folder?>settings_update.php" >

	<h3>Main settings</h3>
	<label>
		Number of pages:
		<input class="" type="number" name="num_of_pages" value="<?=$set['num_of_pages']?>" />
	</label>
	<br />

	<label>
		Ads per page:
		<input class="" type="number" name="num_of_ads_per_page" value="<?=$set['num_of_ads_per_page']?>" />
	</label>
	<br />


	<p>Ad types:</p>

	<label>
		Text
		<input type="checkbox" value="checked" <?=$set['text']?> name="text" />
	</label>

<!--
	<label>
		Image
		<input type="checkbox" value="1" name="image" disabled="">
	</label>
-->

	<label>
		Rich media
		<input type="checkbox" value="checked" <?=$set['rich_media']?> name="rich_media" disabled />
	</label>

<!--
	<label>
		<input type="checkbox" value="1" name="rtb" checked="">
		Real-time bidding
	</label>
-->
	<br /><br />

	<label>Check by stopwords list: <input name="stopwords_check" type="checkbox" value="checked" <?=$set['stopwords_check']?> /></label>

	<br />
	
	<label title="Autofilled list from blocked ads">Check by <a href="<?=$settings_folder?>bad_ads_text.php" target="_blank">bad ad text list</a>: <input name="badadlist_check" type="checkbox" value="checked" <?=$set['badadlist_check']?> /></label>

	<br />

	<label>Check for redirects: <input name="redirects" type="checkbox" value="checked" <?=$set['redirects']?> /></label>

	<br />

	<label><span class="red_arrow" >Check reviewed ads: </span><input name="reviewed" type="checkbox" value="checked" <?=$set['reviewed']?>/></label>

	<br />

	<label>Block AdWords account: <input name="ad_account" type="checkbox" value="checked" <?=$set['ad_account']?>/></label>

	<br />

	<label><span class="red_arrow" >Check only predicted blocks: </span><input name="predicted" type="checkbox" value="checked" <?=$set['predicted']?>/></label>

	<br />

	<label>Mark reviewed as reviewed: <input name="mark_reviewed" type="checkbox" value="checked" <?=$set['mark_reviewed']?>/></label>

	<br />

	<label>Don't save clear ads: <input name="no_save_clear" type="checkbox" value="checked" <?=$set['no_save_clear']?>/></label>

	<br />

	<label title="Block and unblock buttons under ads listed below" >Show block/unblock buttons: <input name="b_unb_buttons" type="checkbox" value="checked" <?=$set['b_unb_buttons']?>/></label>

	<br />

	<label>Get ad stats: <input name="get_stats" type="checkbox" value="checked" <?=$set['get_stats']?>/></label>
	
	<br />

	<label>Enable logs: <input name="log" type="checkbox" value="checked" <?=$set['log']?>/></label>



	<br /><br />
	<label>
		Login (e-mail):<br />
		<input class="login" name="login" type="text"  value="<?=$set['login']?>" placeholder="Will be saved" />
	</label>

	<br /><br />
	
	<label title="0 or empty disables autorun">
	Run every <input type="number" class="run_interval" name="run_interval" id="run_interval" value="<?=$set['run_interval']?>" /> minutes.
	</label>
	
	<br /><br />

	<input class="submit" type="submit" value="Update settings" />

	</form>
</div>


<div class="center_colulmn colulmns">

	<h3>List of stop words</h3>
	<form method="post" action="<?=$settings_folder?>list_update.php" >


	<textarea name="stopwords" id="wordlist" wrap="off" ><?=$stopwords?></textarea>

	<br /><br />

	<input class="submit" type="submit" value="Update list" />

	</form>
</div>

<div class="right_colulmn colulmns">

	<h3 onclick="expand_close('auth_form');" >Google auth</h3>

	<form method="post" action="login.php" id="auth_form" class="auth_form" target="working_frame" style="height: 0px;">

	<label>
		Password:<br />
		<input class="password" type="password" name="password" placeholder="Will not be saved" /><br />
	</label>
	<br />

	<input class="submit" type="submit" value="Login to Google" />

	</form>

	<br /><br /><br />

	<div class="timer"><span id="timer"></span></div>
	
	<a href="search_bad_ads.php" target="working_frame" ><button>Start searching</button></a>
<!--
	<a target="working_frame" onclick="get_time('run_interval');" ><button>Test</button></a>


	<a href="search" target="working_frame" onclick="set_waiting(); return false;" >Start </a>
	<br /><br />
	<a href="img/" target="working_frame" id="wait" >wait</a>
-->

	<br /><br />

	<iframe class="working_frame" name="working_frame" id="working_frame" ></iframe>

	<br /><br />

	<a href="blocked.php" target="_blank" onclick="set_waiting();" ><button>Get blocked ads (in new tab)</button></a>

	<h3 onclick="expand_close('auth_form2');" >Access here password</h3>

	<form method="post" action="set_pass.php" id="auth_form2" class="auth_form" target="working_frame" style="height: 0px;">

	<label>
		<input class="password" type="password" name="pass" placeholder="New password" /><br />
		If password is empty password promt will be disabled
	</label>
	<br />

	<input class="submit" type="submit" value="Change password" />

	</form>


</div>


</div>
</div>





<br class="clear" />


<div class="positoin2">

	<div class="left_right" onclick="move('first_bot', 'left_bot');" >
	⇐
	</div>
	
	<div class="left_right" onclick="move('first_bot', 'right_bot');" >
	⇒
	</div>

</div>

<div class="positoin3">

	<div class="left_right" onclick="move('first_bot', '1_bot');" >
	Blocked for redirect
	</div>
	
	<div class="left_right" onclick="move('first_bot', '2_bot');" >
	Blocked for bad word
	</div>

	<div class="left_right" onclick="move('first_bot', '3_bot');" >
	Clear
	</div>
	
</div>

<div class="second">

<div class="first_bot" id="first_bot" style="right: 0%; ">


<div class="b_left_colulmn colulmns_bot">

	<h3>Blocked for redirect <a onclick="close_ad_column('redirect');" href="delete.php?folder=redirect" target="working_frame" title="Delete all ads in this group" ><img src="img/trash.gif" /></a></h3>

    <div id="ads_list_redirect">
<?php
echo  get_ad_list ('redirect');
?>
    </div>

	<h3>Blocked for blogspot <a onclick="close_ad_column('blogspot');" href="delete.php?folder=blogspot" target="working_frame" title="Delete all ads in this group" ><img src="img/trash.gif" /></a></h3>

    <div id="ads_list_blogspot">
<?php
echo  get_ad_list ('blogspot');
?>
    </div>
    
</div>

<div class="b_center_colulmn colulmns_bot">

	<h3>Blocked for bad word <a onclick="close_ad_column('word');" href="delete.php?folder=word" target="working_frame" title="Delete all ads in this group" ><img src="img/trash.gif" /></a></h3>

    <div id="ads_list_word">
<?php
echo  get_ad_list ('word');
?>
    </div>

</div>


<div class="b_right_colulmn colulmns_bot">

	<h3>Clear <a onclick="close_ad_column('clear');" href="delete.php?folder=clear" target="working_frame" title="Delete all ads in this group" ><img src="img/trash.gif" /></a></h3>

    <div id="ads_list_clear">
<?php
echo  get_ad_list ('clear');
?>
    </div>

</div>


</div>
</div>





</body>
</html>

==> bad_ads_blocker_v1.5.tar.gz: bad_ads_blocker/index.php <==
<?php
include 'functions.php';
file_put_contents($GLOBALS['temp_folder'].'useragent.txt', $_SERVER['HTTP_USER_AGENT']);
$stopwords=file_get_contents($GLOBALS['settings_folder'].'stopwords.txt');
$settings_folder=basename($GLOBALS['settings_folder']).'/';

?><!DOCTYPE html>
<html>
<head>
<title>AdSense bad ad Blocker</title>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<meta name="referrer" content="same-origin" />
<meta name="robots" content="noindex, nofollow" />
<link href="img/favicon.ico" rel="shortcut icon" type="image/x-icon" />
<meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=4, minimum-scale=0.1" />
<style>
<?php
include 'style.css'; 
if(!isset($set['b_unb_buttons'])) include 'b_unb.css'; 
?>

</style>

<?php include 'script.js'; ?>

</head>
<body>


<div class="positoin2">

	<div class="left_right" onclick="move('first', 'left');" >
	⇐
	</div>
	
	<div class="left_right" onclick="move('first', 'right');" >
	⇒
	</div>

</div>

<div class="positoin3">

	<div class="left_right" onclick="move('first', '1');" >
	Main settings
	</div>
	
	<div class="left_right" onclick="move('first', '2');" >
	List of stop words
	</div>

	<div class="left_right" onclick="move('first', '3');" >
	Google auth and other
	</div>
	
</div>


<div class="second">

<div class="first" id="first" style="right: 0%; ">




<div class="left_colulmn colulmns">
	<form method="post" action="<?=@$settings_folder?>settings_update.php" >

	<h3>Main settings</h3>
	<label>
		Number of pages:
		<input class="" type="number" name="num_of_pages" value="<?=@$set['num_of_pages']?>" />
	</label>
	<br />

	<label>
		Ads per page:
		<input class="" type="number" name="num_of_ads_per_page" value="<?=@$set['num_of_ads_per_page']?>" />
	</label>
	<br />


	<p>Ad types:</p>

	<label>
		Text
		<input type="checkbox" value="checked" <?=@$set['text']?> name="text" />
	</label>

<!--
	<label>
		Image
		<input type="checkbox" value="1" name="image" disabled="">
	</label>
-->

	<label>
		Rich media
		<input type="checkbox" value="checked" <?=@$set['rich_media']?> name="rich_media" disabled />
	</label>

<!--
	<label>
		<input type="checkbox" value="1" name="rtb" checked="">
		Real-time bidding
	</label>
-->
	<br /><br />

	<label>Check by stopwords list: <input name="stopwords_check" type="checkbox" value="checked" <?=@$set['stopwords_check']?> /></label>

	<br />
	
	<label title="Autofilled list from blocked ads">Check by <a href="<?=@$settings_folder?>bad_ads_text.php" target="_blank">bad ad text list</a>: <input name="badadlist_check" type="checkbox" value="checked" <?=@$set['badadlist_check']?> /></label>

	<br />

	<label>Check for redirects: <input name="redirects" type="checkbox" value="checked" <?=@$set['redirects']?> /></label>

	<br />

	<label><span class="red_arrow" >Check reviewed ads: </span><input name="reviewed" type="checkbox" value="checked" <?=@$set['reviewed']?>/></label>

	<br />

	<label>Block AdWords account: <input name="ad_account" type="checkbox" value="checked" <?=@$set['ad_account']?>/></label>

	<br />
	
	<label title="Block ads with «blogspot» in URL">Check «blogspot»: <input name="blogspot" type="checkbox" value="checked" <?=@$set['blogspot']?>/></label>

	<br />

	<label><span class="red_arrow" >Check only predicted blocks: </span><input name="predicted" type="checkbox" value="checked" <?=@$set['predicted']?>/></label>

	<br />

	<label>Mark reviewed as reviewed: <input name="mark_reviewed" type="checkbox" value="checked" <?=@$set['mark_reviewed']?>/></label>

	<br />

	<label>Don't save clear ads: <input name="no_save_clear" type="checkbox" value="checked" <?=@$set['no_save_clear']?>/></label>

	<br />

	<label title="Block and unblock buttons under ads listed below" >Show block/unblock buttons: <input name="b_unb_buttons" type="checkbox" value="checked" <?=@$set['b_unb_buttons']?>/></label>

	<br />

	<label>Get ad stats: <input name="get_stats" type="checkbox" value="checked" <?=@$set['get_stats']?>/></label>
	
	<br />

	<label>Enable logs: <input name="log" type="checkbox" value="checked" <?=@$set['log']?>/></label>



	<br /><br />
	<label>
		Login (e-mail):<br />
		<input class="login" name="login" type="text"  value="<?=@$set['login']?>" placeholder="Will be saved" />
	</label>

	<br /><br />
	
	<label title="0 or empty disables autorun">
	Run every <input type="number" class="run_interval" name="run_interval" id="run_interval" value="<?=@$set['run_interval']?>" /> minutes.
	</label>
	
	<br /><br />

	<input class="submit" type="submit" value="Update settings" />

	</form>
</div>


<div class="center_colulmn colulmns">

	<h3>List of stop words</h3>
	<form method="post" action="<?=@$settings_folder?>list_update.php" >


	<textarea name="stopwords" id="wordlist" wrap="off" ><?=$stopwords?></textarea>

	<br /><br />

	<input class="submit" type="submit" value="Update list" />

	</form>
</div>

<div class="right_colulmn colulmns">

	<h3 onclick="expand_close('auth_form');" >Google auth</h3>

	<form method="post" action="login.php" id="auth_form" class="auth_form" target="working_frame" style="height: 0px;">

	<label>
		Password:<br />
		<input class="password" type="password" name="password" placeholder="Will not be saved" /><br />
	</label>
	<br />

	<input class="submit" type="submit" value="Login to Google" />

	</form>

	<br /><br /><br />

	<div class="timer"><span id="timer"></span></div>
	
	<a href="search_bad_ads.php" target="working_frame" ><button>Start searching</button></a>
<!--
	<a target="working_frame" onclick="get_time('run_interval');" ><button>Test</button></a>


	<a href="search" target="working_frame" onclick="set_waiting(); return false;" >Start </a>
	<br /><br />
	<a href="img/" target="working_frame" id="wait" >wait</a>
-->

	<br /><br />

	<iframe class="working_frame" name="working_frame" id="working_frame" ></iframe>

	<br /><br />

	<a href="blocked.php" target="_blank" onclick="set_waiting();" ><button>Get blocked ads (in new tab)</button></a>

	<h3 onclick="expand_close('auth_form2');" >Access here password</h3>

	<form method="post" action="set_pass.php" id="auth_form2" class="auth_form" target="working_frame" style="height: 0px;">

	<label>
		<input class="password" type="password" name="pass" placeholder="New password" /><br />
		If password is empty password promt will be disabled
	</label>
	<br />

	<input class="submit" type="submit" value="Change password" />

	</form>


</div>


</div>
</div>





<br class="clear" />


<div class="positoin2">

	<div class="left_right" onclick="move('first_bot', 'left_bot');" >
	⇐
	</div>
	
	<div class="left_right" onclick="move('first_bot', 'right_bot');" >
	⇒
	</div>

</div>

<div class="positoin3">

	<div class="left_right" onclick="move('first_bot', '1_bot');" >
	Blocked for redirect
	</div>
	
	<div class="left_right" onclick="move('first_bot', '2_bot');" >
	Blocked for bad word
	</div>

	<div class="left_right" onclick="move('first_bot', '3_bot');" >
	Clear
	</div>
	
</div>

<div class="second">

<div class="first_bot" id="first_bot" style="right: 0%; ">


<div class="b_left_colulmn colulmns_bot">

	<h3>Blocked for redirect <a onclick="close_ad_column('redirect');" href="delete.php?folder=redirect" target="working_frame" title="Delete all ads in this group" ><img src="img/trash.gif" /></a></h3>

    <div id="ads_list_redirect">
<?php
echo  get_ad_list ('redirect');
?>
    </div>

	<h3>Blocked for blogspot <a onclick="close_ad_column('blogspot');" href="delete.php?folder=blogspot" target="working_frame" title="Delete all ads in this group" ><img src="img/trash.gif" /></a></h3>

    <div id="ads_list_blogspot">
<?php
echo  get_ad_list ('blogspot');
?>
    </div>
    
</div>

<div class="b_center_colulmn colulmns_bot">

	<h3>Blocked for bad word <a onclick="close_ad_column('word');" href="delete.php?folder=word" target="working_frame" title="Delete all ads in this group" ><img src="img/trash.gif" /></a></h3>

    <div id="ads_list_word">
<?php
echo  get_ad_list ('word');
?>
    </div>

</div>


<div class="b_right_colulmn colulmns_bot">

	<h3>Clear <a onclick="close_ad_column('clear');" href="delete.php?folder=clear" target="working_frame" title="Delete all ads in this group" ><img src="img/trash.gif" /></a></h3>

    <div id="ads_list_clear">
<?php
echo  get_ad_list ('clear');
?>
    </div>

</div>


</div>
</div>





</body>
</html>
